@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006-2007 Imendio AB.
- * Copyright (C) 2007 Collabora Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -27,23 +27,21 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-
-#include <libempathy/empathy-debug.h>
-#include <libempathy/empathy-conf.h>
+#include <gio/gio.h>
 
+#include <libempathy/empathy-utils.h>
 #include "empathy-avatar-chooser.h"
-#include "empathy-preferences.h"
+#include "empathy-conf.h"
 #include "empathy-ui-utils.h"
 
-#define DEBUG_DOMAIN "AvatarChooser"
-
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EMPATHY_AVATAR_CHOOSER_TYPE, EmpathyAvatarChooserPriv))
+#define DEBUG_FLAG EMPATHY_DEBUG_OTHER
+#include <libempathy/empathy-debug.h>
 
 #define AVATAR_SIZE_SAVE 96
 #define AVATAR_SIZE_VIEW 64
 #define DEFAULT_DIR DATADIR"/pixmaps/faces"
 
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyAvatarChooser)
 typedef struct {
 	gchar *image_data;
 	gsize  image_data_size;
@@ -124,10 +122,10 @@ empathy_avatar_chooser_class_init (EmpathyAvatarChooserClass *klass)
 static void
 empathy_avatar_chooser_init (EmpathyAvatarChooser *chooser)
 {
-	EmpathyAvatarChooserPriv *priv;
-
-	priv = GET_PRIV (chooser);
+	EmpathyAvatarChooserPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (chooser,
+		EMPATHY_TYPE_AVATAR_CHOOSER, EmpathyAvatarChooserPriv);
 
+	chooser->priv = priv;
 	gtk_drag_dest_set (GTK_WIDGET (chooser),
 			   GTK_DEST_DEFAULT_ALL,
 			   drop_types,
@@ -188,8 +186,8 @@ avatar_chooser_set_pixbuf (EmpathyAvatarChooser *chooser,
 						&priv->image_data_size,
 						"png",
 						&error, NULL)) {
-			empathy_debug (DEBUG_DOMAIN, "Failed to save pixbuf: %s",
-				       error ? error->message : "No error given");
+			DEBUG ("Failed to save pixbuf: %s",
+				error ? error->message : "No error given");
 			g_clear_error (&error);
 		}
 		image = gtk_image_new_from_pixbuf (pixbuf_view);
@@ -213,8 +211,8 @@ avatar_chooser_set_image_from_file (EmpathyAvatarChooser *chooser,
 	GError    *error = NULL;
 
 	if (!(pixbuf = gdk_pixbuf_new_from_file (filename, &error))) {
-		empathy_debug (DEBUG_DOMAIN, "Failed to load pixbuf from file: %s",
-			       error ? error->message : "No error given");
+		DEBUG ("Failed to load pixbuf from file: %s",
+			error ? error->message : "No error given");
 		g_clear_error (&error);
 	}
 
@@ -328,46 +326,57 @@ avatar_chooser_drag_data_received_cb (GtkWidget          *widget,
 
 	target_type = gdk_atom_name (selection_data->target);
 	if (!strcmp (target_type, URI_LIST_TYPE)) {
-		GnomeVFSHandle   *handle = NULL;
-		GnomeVFSResult    result;
-		GnomeVFSFileInfo  info;
-		gchar            *uri;
+		GFile            *file;
+		GFileInputStream *input_stream;
 		gchar            *nl;
 		gchar            *data = NULL;
 
 		nl = strstr (selection_data->data, "\r\n");
 		if (nl) {
+			gchar *uri;
+
 			uri = g_strndup (selection_data->data,
 					 nl - (gchar*) selection_data->data);
+
+			file = g_file_new_for_uri (uri);
+			g_free (uri);
 		} else {
-			uri = g_strdup (selection_data->data);
+			file = g_file_new_for_uri (selection_data->data);
 		}
 
-		result = gnome_vfs_open (&handle, uri, GNOME_VFS_OPEN_READ);
-		if (result == GNOME_VFS_OK) {
-			result = gnome_vfs_get_file_info_from_handle (handle,
-								      &info,
-								      GNOME_VFS_FILE_INFO_DEFAULT);
-			if (result == GNOME_VFS_OK) {
-				GnomeVFSFileSize data_size;
+		input_stream = g_file_read (file, NULL, NULL);
 
-				data = g_malloc (info.size);
+		if (input_stream != NULL) {
+			GFileInfo *info;
+			
+			info = g_file_query_info (file,
+						  G_FILE_ATTRIBUTE_STANDARD_SIZE,
+						  0, NULL, NULL);
+			if (info != NULL) {
+				goffset size;
+				gssize bytes_read;
+				
+				size = g_file_info_get_size (info);
+				data = g_malloc (size);
 
-				result = gnome_vfs_read (handle, data, info.size, &data_size);
-				if (result == GNOME_VFS_OK) {
+				bytes_read = g_input_stream_read (G_INPUT_STREAM (input_stream),
+								  data, size,
+								  NULL, NULL);
+				if (bytes_read != -1) {
 					avatar_chooser_set_image_from_data (chooser,
 									    data,
-									    data_size);
+									    (gsize) bytes_read);
 					handled = TRUE;
-				} else {
-					g_free (data);
 				}
+
+				g_free (data);
+				g_object_unref (info);
 			}
 
-			gnome_vfs_close (handle);
+			g_object_unref (input_stream);
 		}
-
-		g_free (uri);
+		
+		g_object_unref (file);
 	}
 
 	gtk_drag_finish (context, handled, FALSE, time);
@@ -529,7 +538,7 @@ avatar_chooser_clicked_cb (GtkWidget            *button,
 GtkWidget *
 empathy_avatar_chooser_new (void)
 {
-	return g_object_new (EMPATHY_AVATAR_CHOOSER_TYPE, NULL);
+	return g_object_new (EMPATHY_TYPE_AVATAR_CHOOSER, NULL);
 }
 
 void
