@@ -32,7 +32,7 @@
 #include <libmissioncontrol/mission-control.h>
 
 #include <libempathy/empathy-contact-factory.h>
-#include <libempathy/empathy-debug.h>
+#include <libempathy/empathy-dispatcher.h>
 #include <libempathy/empathy-utils.h>
 
 #include <libempathy-gtk/empathy-ui-utils.h>
@@ -40,8 +40,6 @@
 #include "empathy-new-message-dialog.h"
 #include "empathy-account-chooser.h"
 
-#define DEBUG_DOMAIN "NewMessageDialog"
-
 typedef struct {
 	GtkWidget *dialog;
 	GtkWidget *table_contact;
@@ -70,10 +68,10 @@ new_message_dialog_response_cb (GtkWidget               *widget,
 	}
 
 	if (response == 1) {
-		empathy_call_with_contact_id (account, id);
+		empathy_dispatcher_call_with_contact_id (account, id);
 	}	
 	else if (response == 2) {
-		empathy_chat_with_contact_id (account, id);
+		empathy_dispatcher_chat_with_contact_id (account, id);
 	}
 
 	g_object_unref (account);
@@ -157,10 +155,6 @@ empathy_new_message_dialog_show (GtkWindow *parent)
 	gtk_widget_set_sensitive (dialog->button_chat, FALSE);
 	gtk_widget_set_sensitive (dialog->button_call, FALSE);
 
-#ifndef HAVE_VOIP
-	gtk_widget_hide (dialog->button_call);
-#endif
-
 	gtk_widget_show (dialog->dialog);
 
 	return dialog->dialog;
