@@ -24,28 +24,21 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-utils.h>
 
 #include "empathy-chat.h"
 #include "empathy-conf.h"
-#include "empathy-preferences.h"
 #include "empathy-theme.h"
 #include "empathy-smiley-manager.h"
 
-#define DEBUG_DOMAIN "Theme"
-
 /* Number of seconds between timestamps when using normal mode, 5 minutes. */
 #define TIMESTAMP_INTERVAL 300
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EMPATHY_TYPE_THEME, EmpathyThemePriv))
-
-typedef struct _EmpathyThemePriv EmpathyThemePriv;
-
-struct _EmpathyThemePriv {
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyTheme)
+typedef struct {
 	EmpathySmileyManager *smiley_manager;
 	gboolean show_avatars;
-};
+} EmpathyThemePriv;
 
 static void         theme_finalize            (GObject            *object);
 static void         theme_get_property        (GObject            *object,
@@ -93,12 +86,12 @@ empathy_theme_class_init (EmpathyThemeClass *class)
 }
 
 static void
-empathy_theme_init (EmpathyTheme *presence)
+empathy_theme_init (EmpathyTheme *theme)
 {
-	EmpathyThemePriv *priv;
-
-	priv = GET_PRIV (presence);
+	EmpathyThemePriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (theme,
+		EMPATHY_TYPE_THEME, EmpathyThemePriv);
 
+	theme->priv = priv;
 	priv->smiley_manager = empathy_smiley_manager_new ();
 }
 
@@ -169,7 +162,7 @@ empathy_theme_maybe_append_date_and_time (EmpathyTheme        *theme,
 	date = empathy_message_get_date_and_time (message, &timestamp);
 
 	last_date = g_date_new ();
-	g_date_set_time (last_date, empathy_chat_view_get_last_timestamp (view));
+	g_date_set_time_t (last_date, empathy_chat_view_get_last_timestamp (view));
 
 	append_date = FALSE;
 	append_time = FALSE;
@@ -200,7 +193,7 @@ empathy_theme_update_view (EmpathyTheme    *theme,
 		g_error ("Theme must override update_view");
 	}
 
-	return EMPATHY_THEME_GET_CLASS(theme)->update_view (theme, view);
+	EMPATHY_THEME_GET_CLASS(theme)->update_view (theme, view);
 }
 
 void
