@@ -25,6 +25,7 @@
 
 #include <telepathy-glib/proxy-subclass.h>
 #include <telepathy-glib/dbus.h>
+#include <telepathy-glib/interfaces.h>
 
 #include <extensions/extensions.h>
 
@@ -281,9 +282,6 @@ tp_call_member_added_cb (EmpathyTpGroup *group,
       g_object_notify (G_OBJECT (call), "is-incoming");
       g_object_notify (G_OBJECT (call), "contact");
       g_object_notify (G_OBJECT (call), "status");
-      tp_call_request_streams_for_capabilities (call,
-          EMPATHY_CAPABILITIES_AUDIO);
-
     }
 
   if (priv->status == EMPATHY_TP_CALL_STATUS_PENDING &&
@@ -841,3 +839,14 @@ empathy_tp_call_stop_tone (EmpathyTpCall *call)
       "stoping tone", NULL, G_OBJECT (call));
 }
 
+gboolean
+empathy_tp_call_has_dtmf (EmpathyTpCall *call)
+{
+  EmpathyTpCallPriv *priv = GET_PRIV (call);
+
+  g_return_val_if_fail (EMPATHY_IS_TP_CALL (call), FALSE);
+
+  return tp_proxy_has_interface_by_id (priv->channel,
+      TP_IFACE_QUARK_CHANNEL_INTERFACE_DTMF);
+}
+
