@@ -177,18 +177,16 @@ megaphone_applet_update_icon (MegaphoneApplet *applet)
 							      "avatar_token",
 							      NULL);
 		if (!G_STR_EMPTY (avatar_token)) {
-			avatar = empathy_avatar_new_from_cache (avatar_token);
+			empathy_contact_load_avatar_cache (priv->contact, avatar_token);
+			avatar = empathy_contact_get_avatar (priv->contact);
 		}
 		g_free (avatar_token);
-	} else {
-		empathy_avatar_ref (avatar);
 	}
 
 	if (avatar) {
 		avatar_pixbuf = empathy_pixbuf_from_avatar_scaled (avatar,
 								   priv->image_size - 2,
 								   priv->image_size - 2);
-		empathy_avatar_unref (avatar);
 	} else {
 		GtkIconTheme *icon_theme;
 
@@ -254,7 +252,7 @@ megaphone_applet_update_contact (MegaphoneApplet *applet)
 		g_free (tip);
 	} else {
 		gtk_widget_set_tooltip_markup (GTK_WIDGET (applet),
-					       "Please configure a contact.");
+					       _("Please configure a contact."));
 	}
 
 }
@@ -347,7 +345,7 @@ megaphone_applet_show_preferences (MegaphoneApplet *applet)
 	EmpathyContactListStore *contact_store;
 	EmpathyContactManager   *contact_manager;
 
-	dialog = gtk_dialog_new_with_buttons ("Select contact...",
+	dialog = gtk_dialog_new_with_buttons (_("Select contact..."),
 					      NULL, 0,
 					      GTK_STOCK_CANCEL,
 					      GTK_RESPONSE_REJECT,
